/****************************************************************************
** Meta object code from reading C++ file 'play_word_mediator.h'
**
** Created: Sat Feb 6 15:10:01 2010
**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../qt/play_word_mediator.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'play_word_mediator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 61
#error "This file was generated using the moc from 4.5.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_PlayWordMediator[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   12, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

 // signals: signature, parameters, type, tag, flags
      18,   17,   17,   17, 0x05,
      37,   32,   17,   17, 0x05,

 // slots: signature, parameters, type, tag, flags
      60,   17,   17,   17, 0x08,
      87,   17,   17,   17, 0x08,
     122,  116,   17,   17, 0x08,
     157,   17,   17,   17, 0x08,
     187,   17,   17,   17, 0x08,
     222,  212,   17,   17, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_PlayWordMediator[] = {
    "PlayWordMediator\0\0gameUpdated()\0iMsg\0"
    "notifyProblem(QString)\0"
    "lineEditPlay_textChanged()\0"
    "lineEditPlay_returnPressed()\0iText\0"
    "lineEditCoord_textChanged(QString)\0"
    "lineEditCoord_returnPressed()\0"
    "pushButtonPlay_clicked()\0iNewCoord\0"
    "updateCoord(Coord)\0"
};

const QMetaObject PlayWordMediator::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PlayWordMediator,
      qt_meta_data_PlayWordMediator, 0 }
};

const QMetaObject *PlayWordMediator::metaObject() const
{
    return &staticMetaObject;
}

void *PlayWordMediator::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_PlayWordMediator))
        return static_cast<void*>(const_cast< PlayWordMediator*>(this));
    return QObject::qt_metacast(_clname);
}

int PlayWordMediator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: gameUpdated(); break;
        case 1: notifyProblem((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: lineEditPlay_textChanged(); break;
        case 3: lineEditPlay_returnPressed(); break;
        case 4: lineEditCoord_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: lineEditCoord_returnPressed(); break;
        case 6: pushButtonPlay_clicked(); break;
        case 7: updateCoord((*reinterpret_cast< const Coord(*)>(_a[1]))); break;
        default: ;
        }
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PlayWordMediator::gameUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void PlayWordMediator::notifyProblem(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_END_MOC_NAMESPACE
